@@ -62,6 +62,7 @@ def _create_reader(numbering, content_types, relationships, styles, docx_file):
             
         is_bold = properties.find_child("w:b")
         is_italic = properties.find_child("w:i")
+        is_underline = properties.find_child("w:u")
         
         return _read_xml_elements(element.children) \
             .map(lambda children: documents.run(
@@ -70,6 +71,7 @@ def _create_reader(numbering, content_types, relationships, styles, docx_file):
                 style_name=style_name,
                 is_bold=is_bold,
                 is_italic=is_italic,
+                is_underline=is_underline,
             ))
 
 
